@@ -68,12 +68,14 @@ def std_deps(dep_type, filepath, verbose=False, prestr=''):
             elif verbose:
                 print(f'{package} already installed')
         elif package.lower() not in exist_list:
-            if not verbose: l.chain(f'{package}', prestr + '\t')
+            if not verbose:
+                l.chain(f'{package}', prestr + '\t')
             p = sp.run(f'{install_cmd[dep_type]} {package}',
                        shell=True,
                        stdout=(None if verbose else sp.PIPE),
                        stderr=(None if verbose else sp.PIPE))
-            if not verbose: l.end(p.returncode)
+            if not verbose:
+                l.end(p.returncode)
 
 
 def script(filepath, input_args, verbose=False, forced=False, mode='install'):
@@ -142,7 +144,8 @@ def script(filepath, input_args, verbose=False, forced=False, mode='install'):
             for key, val in sub_map + sub_map_key:
                 disp_title = disp_title.replace(key, val)
         # Anim start
-        if not verbose: l.chain(f'{disp_title}', '\t')
+        if not verbose:
+            l.chain(f'{disp_title}', '\t')
         # Final return code
         retcode = 0
         # Loop through commands under section
@@ -156,10 +159,12 @@ def script(filepath, input_args, verbose=False, forced=False, mode='install'):
             retcode += p.returncode
             # If blocking section, close if retcode is not 0
             if retcode != 0 and is_blocking:
-                if not verbose: l.end(retcode)
+                if not verbose:
+                    l.end(retcode)
                 return
         # Anim end
-        if not verbose: l.end(retcode)
+        if not verbose:
+            l.end(retcode)
     # Clean Up and Back to Cur Dir
     if script_meta["temp_dir"] and mode in ['install', 'update']:
         shutil.rmtree(TMP_DIR)
